@@ -39,7 +39,7 @@ char copyright[] =
 #endif /* not lint */
 
 #ifndef lint
-static char rcsid[] = "$Id: edquota.c,v 1.6 1995/07/23 09:58:06 mvw Exp mvw $";
+static char rcsid[] = "$Id: edquota.c,v 1.7 1996/07/02 19:41:28 mvw Exp $";
 #endif /* not lint */
 
 /*
@@ -49,6 +49,7 @@ static char rcsid[] = "$Id: edquota.c,v 1.6 1995/07/23 09:58:06 mvw Exp mvw $";
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/file.h>
+#include <asm/types.h>
 #include <linux/quota.h>
 #include <errno.h>
 #include <mntent.h>
@@ -111,6 +112,9 @@ main(int argc, char **argv)
    argc -= optind;
    argv += optind;
 
+   if (tflag && argc != 0)
+      usage();
+
    if (pflag) {
       if ((protoid = getentry(protoname, quotatype)) == -1)
          exit(1);
