@@ -9,8 +9,8 @@
  *          Program to check disk quotas.
  * 
  * Authors:
- *          Disk reading routines: Edvard Tuinder <ed@ow.org> <ed@tnix.net>
- *          Quota storing routines: Marco van Wieringen <mvw@planets.ow.org> <mvw@tnix.net>
+ *          Disk reading routines: Edvard Tuinder <ed@elm.net>
+ *          Quota storing routines: Marco van Wieringen <mvw@planets.elm.net>
  *
  *          This program is free software; you can redistribute it and/or
  *          modify it under the terms of the GNU General Public License as
@@ -24,6 +24,7 @@
 #include <sys/stat.h>
 #include <stdio.h>
 #include <string.h>
+#include <asm/types.h>
 #include <linux/quota.h>
 #include <stdarg.h>
 #include <sys/file.h>
@@ -42,7 +43,7 @@
 #define NODQUOT (struct dquot *)NULL
 
 #ifndef lint
-static char RCS_checkquota[] = "$Id: quotacheck.c,v 2.12 1995/07/23 09:58:06 mvw Exp mvw $";
+static char RCS_checkquota[] = "$Id: quotacheck.c,v 2.14 1996/11/17 16:59:46 mvw Exp mvw $";
 #endif
 
 struct dquot {
@@ -185,7 +186,7 @@ static inline void blit()
 
 void usage()
 {
-   fputs("Usage:\n\tquotacheck [-g] [-u] [-vd] -a\n", stderr);
+   fputs("Usage:\n\tquotacheck [-g] [-u] [-R] [-vd] -a\n", stderr);
    fputs("\tquotacheck [-g] [-u] [-vd] filesys ...\n", stderr);
    exit(1);
 }
@@ -195,13 +196,13 @@ int main(int argc, char **argv)
    FILE *fp;
    int cnt, ch;
    struct stat st;
-   char aflag = 0, gflag = 0, uflag = 0;
+   char aflag = 0, gflag = 0, uflag = 0, Rflag = 0;
    unsigned done;
    int argnum;
    char *usr_qfnp, *grp_qfnp;
    register struct mntent *mnt;
 
-   while ((ch = getopt(argc, argv, "avugd")) != EOF) {
+   while ((ch = getopt(argc, argv, "avugdR")) != EOF) {
       switch (ch) {
          case 'a':
             aflag++;
@@ -220,6 +221,9 @@ int main(int argc, char **argv)
             vflag++;
 	    setbuf(stdout, (char *)NULL);
             break;
+	 case 'R':
+	    Rflag++;
+	    break;
          default:
             usage();
       }
@@ -240,20 +244,19 @@ int main(int argc, char **argv)
    while ((mnt = getmntent(fp)) != (struct mntent *) NULL) {
       check_usr = check_grp = 0;
 
-      if (!aflag) { /* .. or: argc != 0 */
-	/* If the user specified a fs/part name, then check only
-	   those, and skip all others */
+      if (!aflag) {
 	if (((argnum = oneof(mnt->mnt_dir, argv, argc)) >= 0) ||
 	    ((argnum = oneof(mnt->mnt_fsname, argv, argc)) >= 0)) {
-	  done |= (1<<argnum);
+	  done |= (1 << argnum);
 	} else
 	  continue;
       } else {
-	/* If 'all', then skip every fs, which is not marked as 'auto'
-	   AND user or group quota */
 	if (hasmntopt(mnt, MNTOPT_NOAUTO) ||
 	    hasmntopt(mnt, MNTOPT_NOQUOTA))
 	  continue;
+        else
+	   if (aflag && Rflag && !strcmp(mnt->mnt_dir, "/"))
+	      continue;
       }
 
       if (gflag && hasquota(mnt, GRPQUOTA, &grp_qfnp))
