@@ -39,7 +39,7 @@ char copyright[] =
 #endif /* not lint */
 
 #ifndef lint
-static char rcsid[] = "$Id: quotaon.c,v 1.3 1995/05/15 13:49:14 mvw Exp $";
+static char rcsid[] = "$Id: quotaon.c,v 1.4 1996/07/02 19:41:28 mvw Exp $";
 #endif /* not lint */
 
 /*
@@ -48,10 +48,7 @@ static char rcsid[] = "$Id: quotaon.c,v 1.3 1995/05/15 13:49:14 mvw Exp $";
 #include <sys/param.h>
 #include <sys/file.h>
 #include <sys/mount.h>
-#define __KERNEL__
-#include <linux/kdev_t.h>
-#include <linux/wait.h>
-#undef __KERNEL__
+#include <asm/types.h>
 #include <linux/quota.h>
 #include <stdio.h>
 #include <string.h>
@@ -119,20 +116,35 @@ main(int argc, char **argv)
       if (aflag) {
          if (hasmntopt(mnt, MNTOPT_NOAUTO))
             continue;
-         if (gflag && hasquota(mnt, GRPQUOTA, &qfnp))
-            errs += quotaonoff(mnt, offmode, GRPQUOTA, qfnp);
-         if (uflag && hasquota(mnt, USRQUOTA, &qfnp))
-            errs += quotaonoff(mnt, offmode, USRQUOTA, qfnp);
-         continue;
-      }
-      if ((argnum = oneof(mnt->mnt_dir, argv, argc)) >= 0 ||
-          (argnum = oneof(mnt->mnt_fsname, argv, argc)) >= 0) {
-         done |= 1 << argnum;
-         if (gflag && hasquota(mnt, GRPQUOTA, &qfnp))
-            errs += quotaonoff(mnt, offmode, GRPQUOTA, qfnp);
-         if (uflag && hasquota(mnt, USRQUOTA, &qfnp))
-            errs += quotaonoff(mnt, offmode, USRQUOTA, qfnp);
+      } else {
+         if ((argnum = oneof(mnt->mnt_dir, argv, argc)) >= 0 ||
+             (argnum = oneof(mnt->mnt_fsname, argv, argc)) >= 0)
+            done |= 1 << argnum;
+         else 
+            continue;
       }
+
+#if defined(MNTOPT_RSQUASH)
+      if (offmode && gflag && hasmntopt(mnt, MNTOPT_RSQUASH))
+         errs += quotarsquashonoff(mnt, offmode, USRQUOTA);
+#endif
+      if (gflag && hasquota(mnt, GRPQUOTA, &qfnp))
+         errs += quotaonoff(mnt, offmode, GRPQUOTA, qfnp);
+#if defined(MNTOPT_RSQUASH)
+      if (!offmode && gflag && hasmntopt(mnt, MNTOPT_RSQUASH))
+         errs += quotarsquashonoff(mnt, offmode, USRQUOTA);
+#endif
+
+#if defined(MNTOPT_RSQUASH)
+      if (offmode && uflag && hasmntopt(mnt, MNTOPT_RSQUASH))
+         errs += quotarsquashonoff(mnt, offmode, USRQUOTA);
+#endif
+      if (uflag && hasquota(mnt, USRQUOTA, &qfnp))
+         errs += quotaonoff(mnt, offmode, USRQUOTA, qfnp);
+#if defined(MNTOPT_RSQUASH)
+      if (!offmode && uflag && hasmntopt(mnt, MNTOPT_RSQUASH))
+         errs += quotarsquashonoff(mnt, offmode, USRQUOTA);
+#endif
    }
    endmntent(fp);
 
@@ -174,6 +186,24 @@ quotaonoff(struct mntent *mnt, int offmode, int type, char *qfpathname)
    return (0);
 }
 
+#if defined(MNTOPT_RSQUASH)
+quotarsquashonoff(struct mntent *mnt, int offmode, int type)
+{
+   int mode;
+
+   mode = (offmode) ? 0 : 1;
+   if (quotactl(QCMD(Q_RSQUASH, type), mnt->mnt_fsname, 0, (caddr_t) &mode) < 0) {
+      fprintf(stderr, "quotaon: set root_squash on");
+      perror(mnt->mnt_fsname);
+      return (1);
+   }
+   if (vflag)
+      printf("%s: %s root_squash turned %s\n", mnt->mnt_fsname,
+             qfextension[type], offmode ? "off" : "on");
+   return (0);
+}
+#endif
+
 /*
  * Check to see if target appears in list of size cnt.
  */
