@@ -8,9 +8,9 @@
  * 
  *          Program to query for the internal statistics.
  * 
- * Author:  Marco van Wieringen <mvw@planets.ow.nl> <mvw@tnix.net>
+ * Author:  Marco van Wieringen <mvw@planets.elm.net>
  *
- * Version: $Id: quotastats.c,v 1.1 1995/11/02 13:56:44 mvw Exp mvw $
+ * Version: $Id: quotastats.c,v 1.3 1996/11/17 16:59:46 mvw Exp mvw $
  *
  *          This program is free software; you can redistribute it and/or
  *          modify it under the terms of the GNU General Public License as
@@ -19,6 +19,7 @@
  */
 
 #include <sys/types.h>
+#include <asm/types.h>
 #include <linux/quota.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -38,7 +39,6 @@ static inline int print_stats(struct dqstats *dqstats)
    fprintf(stdout, "Number of dquot writes: %ld\n", dqstats->writes);
    fprintf(stdout, "Number of quotafile syncs: %ld\n", dqstats->syncs);
    fprintf(stdout, "Number of dquot cache hits: %ld\n", dqstats->cache_hits);
-   fprintf(stdout, "Number of pages allocated: %ld\n", dqstats->pages_allocated);
    fprintf(stdout, "Number of allocated dquots: %ld\n", dqstats->allocated_dquots);
    fprintf(stdout, "Number of free dquots: %ld\n", dqstats->free_dquots);
    fprintf(stdout, "Number of in use dquot entries (user/group): %ld\n",
