@@ -9,9 +9,9 @@
  *
  *          This part does the lookup of the info.
  *
- * Version: $Id: rquota_server.c,v 2.8 1995/07/23 09:58:06 mvw Exp mvw $
+ * Version: $Id: rquota_server.c,v 2.9 1996/11/17 16:59:46 mvw Exp mvw $
  *
- * Author:  Marco van Wieringen <mvw@planets.ow.nl> <mvw@tnix.net>
+ * Author:  Marco van Wieringen <mvw@planets.elm.net>
  *
  *          This program is free software; you can redistribute it and/or
  *          modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
 #include <sys/file.h>
 #include <sys/stat.h>
 #include <sys/param.h>
+#include <asm/types.h>
 #include <linux/quota.h>
 #include <dirent.h>
 #include <paths.h>
@@ -32,7 +33,7 @@
 #define TYPE_EXTENDED	0x01
 #define ACTIVE		0x02
 
-#ifdef OWLD
+#ifdef ELM
 #define _PATH_DEV_DSK   "/dev/dsk/"
 #else
 #define _PATH_DEV_DSK   "/dev/"
@@ -72,6 +73,9 @@ char *nfsmount_to_devname(char *pathname, int *blksize)
       if (stat(devicename, &st) == -1)
          continue;
 
+      if (!S_ISBLK(st.st_mode))
+         continue;
+
       if (device == st.st_rdev)
          break;
    }
